Installation
############

This page describes how to get and set-up Canaille. For a quick first run without too much details, please check the :doc:`../tutorials/getting-started` chapter.

Canaille is available through different methods.
Choose the installation method that best fits your needs:

.. toctree::
   :maxdepth: 1

   installation/docker
   installation/binary
   installation/python
   installation/packages
